/**
 * point.java -- a 3D point.  Also some miscellaneous useful routines.
 *
 * By Bob Jenkins, July 1998
 * Permission granted to use, reuse, rewrite this without notifying me.
 */
import java.awt.*;

// a 3D point
final public class point {
  public double x,y,z;    // value of point

  point(double x, double y, double z) { this.x=x; this.y=y; this.z=z; }
  public final void scale(double a)   { x=x*a; y=y*a; z=z*a; }
  public final void copy(point p) { x=p.x; y=p.y; z=p.z; }
  public final void zero()        { x=0.0; y=0.0; z=0.0; }
  public String toString()        { return "("+(float)x+","+(float)y+","+(float)z+")"; }
  public final double dot(point p){ return p.x*x+p.y*y+p.z*z; }

  // a = b-c
  public static final void minusx(point a, point b, point c) {
    a.x=b.x-c.x;  a.y=b.y-c.y;  a.z=b.z-c.z;
  }

  // a = b+c
  public static final void plusx(point a, point b, point c) {
    a.x=b.x+c.x;  a.y=b.y+c.y;  a.z=b.z+c.z;
  }

  // x = y+az
  public static final void plusax(point x, point y, double a, point z) {
    x.x=y.x+a*z.x;  x.y=y.y+a*z.y;  x.z=y.z+a*z.z;
  }

  public static double s2d(String s, double dflt) {
    if (s==null) {
      return dflt;
    } else {
      try {
	return Double.valueOf(s).doubleValue();
      } catch (NumberFormatException e) {
	return dflt;
      }
    }
  }

  public static Color s2c(String s, Color dflt) {
    if (s==null) {
      return dflt;
    } else {
      return new Color(Integer.parseInt(s, 16));
    }
  }
}

